function neuralDecision (stimulus, ncells, ntsteps, threshold)
% function neuralDecision (stimulus, ncells, ntsteps, threshold)
% generates firing rate values over time for two anti-thetical pools of MT 
% neurons whose preferred motion direction is directly left or right
% (representing evidence for two mutually explusive alternatives) and
% models LIP firing rate as temporal integration of the difference between 
% the MT pools followed by a decision based on threshold (Wallisch p280-1) 

% stimulus is a number between 1 and 202 that specifies the stimulus
% condition to simulate (mtneurons function allows 202 stimulus conditions, 
% with stimulus = 102 corresponding condition that yields chance response.
% ncells is number of MT cells in each of the two pools (to be summed)
% ntsteps is the number of time steps in the simulation
% threshold is the level of total LIP response that yields a L/R decision

% firing rates at each time step for MT cells that prefer left and right
leftrates = zeros(1,ncells);        % preferred direction at index 102-51
rightrates = zeros(1,ncells);       % preferred direction at index 102+51
sumright = zeros(1,ntsteps);        % sum of pool of right MT neurons
sumleft = zeros(1,ntsteps);         % sum of pool of left MT neurons
ratediffs = zeros(1,ntsteps);       % stores difference sum(R)-sum(L) rates 
liprate = zeros(1,ntsteps);         % rate of one LIP neuron at each time step
for i = 2:ntsteps
    % vectors of left and right rates for this time step
    leftrates =  mtneurons(102-51, stimulus, ncells);
    rightrates = mtneurons(102+51, stimulus, ncells);
    sumleft(i) = sum(leftrates);       % summing spikes per time step
    sumright(i) = sum(rightrates);     % sums here should be over neurons
    % R-L so positive means choose right, negative means choose left 
    ratediffs(i) = sumright(i)-sumleft(i); 
    % LIP cell integrates MT cell rate diffs over time
    liprate(i) = liprate(i-1)+ratediffs(i); 
end     % time loop

% plot summed responses of MT left/right neurons, LIP activation, threshold
% figure(1)
plot(sumleft,'r')
hold on
plot(sumright,'b')
if (stimulus > 102)
    lipColor = 'm';
elseif (stimulus < 102)
    lipColor = 'g';
else
    lipColor = 'c';
end
plot(liprate,lipColor)
plot([1 ntsteps], [threshold threshold], 'm')
plot([1 ntsteps], [-threshold -threshold], 'g')
axis([1 ntsteps -1.1*threshold 1.1*threshold])
text(5,threshold-10,'right','FontSize',16,'Color','m')
text(5,-threshold+10,'left','FontSize',16,'Color','g')
legend('MT-left','MT-right','LIP', 'threshold','Location','NorthEast')
xlabel('Time step')
ylabel('Firing rate per time step')
title(['Stimulus ' num2str(stimulus) ])














